#!/bin/sh

if [ "$#" -ne 3 ]; then
    echo "USAGE: $0 <on/off> <event folder> <replacement folder>";
    echo "Argument 2 must be path to events folder, eg. /etc/actionengine/user/1/"
    echo "Argument 3 must be a path to an non existing folder location for overriding files"
    exit 1
fi

ACTION="$1"
EVENT_FOLDER="$2"
OVERRIDE_FOLDER="$3"

case "$ACTION" in

    "on")

        if [ ! -d "$EVENT_FOLDER" ]; then
            echo "ERROR: $EVENT_FOLDER is not a directory"
            exit 1
        fi

        if [ -e "$OVERRIDE_FOLDER" ]; then
            if find $OVERRIDE_FOLDER -name *com.axis.action* > /dev/null; then
                    while umount $EVENT_FOLDER 2> /dev/null; do
                        :
                    done
                    rm -rf $OVERRIDE_FOLDER
            else
                echo "ERROR: $OVERRIDE_FOLDER already exists, specify an ampty path"
                exit 1
            fi
        fi

        # Copy the whole template folder
        cp -r $EVENT_FOLDER $OVERRIDE_FOLDER

        # Remove event actions that shouldn't be allowed (send_image, send_videoclip and record)
        F=$(find "$OVERRIDE_FOLDER" -name *send*)
        rm $F
        F=$(find "$OVERRIDE_FOLDER" -name *recording*)
        rm $F


        # bind mount the new folder to override the old one
        if ! mount | grep -w ${EVENT_FOLDER%/}; then
            mount --bind $OVERRIDE_FOLDER $EVENT_FOLDER
        fi

        ;;

    "off")

        if [ ! -d "$EVENT_FOLDER" ]; then
            echo "ERROR: $EVENT_FOLDER is not a directory"
            exit 1
        fi

        while umount $EVENT_FOLDER 2> /dev/null; do
            :
        done

        if [ ! -d "$OVERRIDE_FOLDER" ]; then
            echo "WARNING: $OVERRIDE_FOLDER is not a directory"
        else
            if find $OVERRIDE_FOLDER -name *com.axis.action.* > /dev/null; then
                rm -rf $OVERRIDE_FOLDER
            else
                echo "WARNING: Didn't remove $OVERRIDE_FOLDER directory, doesn't look like an action template folder" 
            fi
        fi

        ;;

    *)
        echo "ERROR: Action must be \"on\" or \"off\""
        exit 1

        ;;

esac


